@@ -6,9 +6,9 @@ package mgostore
 import (
 	"context"
 
+	"github.com/go-macaroon-bakery/macaroon-bakery/v3/bakery/mgorootkeystore"
 	mgo "github.com/juju/mgo/v2"
 	errgo "gopkg.in/errgo.v1"
-	"gopkg.in/macaroon-bakery.v3/bakery/mgorootkeystore"
 )
 
 const macaroonCollection = "macaroons"
